Class: Aws::CostandUsageReportService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CostandUsageReportService::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-costandusagereportservice/client.rb
Overview
An API client for CostandUsageReportService. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::CostandUsageReportService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_report_definition(params = {}) ⇒ Types::DeleteReportDefinitionResponse
Deletes the specified report.
-
#describe_report_definitions(params = {}) ⇒ Types::DescribeReportDefinitionsResponse
Lists the Amazon Web Services Cost and Usage Report available to this account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags associated with the specified report definition.
-
#modify_report_definition(params = {}) ⇒ Struct
Allows you to programmatically update your report preferences.
-
#put_report_definition(params = {}) ⇒ Struct
Creates a new report using the description that you provide.
-
#tag_resource(params = {}) ⇒ Struct
Associates a set of tags with a report definition.
-
#untag_resource(params = {}) ⇒ Struct
Disassociates a set of tags from a report definition.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-costandusagereportservice/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
863 864 865 |
# File 'lib/aws-sdk-costandusagereportservice/client.rb', line 863 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
866 867 868 |
# File 'lib/aws-sdk-costandusagereportservice/client.rb', line 866 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'lib/aws-sdk-costandusagereportservice/client.rb', line 836 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CostandUsageReportService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-costandusagereportservice' context[:gem_version] = '1.89.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_report_definition(params = {}) ⇒ Types::DeleteReportDefinitionResponse
Deletes the specified report. Any tags associated with the report are also deleted.
518 519 520 521 |
# File 'lib/aws-sdk-costandusagereportservice/client.rb', line 518 def delete_report_definition(params = {}, = {}) req = build_request(:delete_report_definition, params) req.send_request() end |
#describe_report_definitions(params = {}) ⇒ Types::DescribeReportDefinitionsResponse
Lists the Amazon Web Services Cost and Usage Report available to this account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
617 618 619 620 |
# File 'lib/aws-sdk-costandusagereportservice/client.rb', line 617 def describe_report_definitions(params = {}, = {}) req = build_request(:describe_report_definitions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags associated with the specified report definition.
648 649 650 651 |
# File 'lib/aws-sdk-costandusagereportservice/client.rb', line 648 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#modify_report_definition(params = {}) ⇒ Struct
Allows you to programmatically update your report preferences.
695 696 697 698 |
# File 'lib/aws-sdk-costandusagereportservice/client.rb', line 695 def modify_report_definition(params = {}, = {}) req = build_request(:modify_report_definition, params) req.send_request() end |
#put_report_definition(params = {}) ⇒ Struct
Creates a new report using the description that you provide.
768 769 770 771 |
# File 'lib/aws-sdk-costandusagereportservice/client.rb', line 768 def put_report_definition(params = {}, = {}) req = build_request(:put_report_definition, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Associates a set of tags with a report definition.
800 801 802 803 |
# File 'lib/aws-sdk-costandusagereportservice/client.rb', line 800 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Disassociates a set of tags from a report definition.
827 828 829 830 |
# File 'lib/aws-sdk-costandusagereportservice/client.rb', line 827 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
856 857 858 |
# File 'lib/aws-sdk-costandusagereportservice/client.rb', line 856 def waiter_names [] end |